# Cudo Compute
To use this client install cudoctl and run ``./cudoctl init`` follow the steps to enter your API key and choose your project.  

Then when you call cudo_api in python it will grab your API key from the yaml file created by cudoctl.

```bash
pip install cudo-compute
```

```python
from cudo_compute import cudo_api

api = cudo_api.virtual_machines()
vms = api.list_vms(cudo_api.project_id())
```

More examples of various api calls can be found in ``examples``. 



# Advanced Users / Development
The code is generated by swagger codegen cli.

Most code is generated in github actions see .github/workflows the generated code is put into a /src/cudo_compute directory
The code gets modified and the helpers get copied in from /helpers.

``./codegen.sh`` generates docs directory with source code and documentation.

If you wish to customise how the API key or project is selected see the code in the helpers directory. 